@@ -56,6 +56,8 @@ historical = [
 			      (None,u'(..*[^aeouyäö]o)ri',u'symboli_ri'),
 			      (None,u'(..*[^aeouyäö]o)vi',u'symboli_vi'),
 			      (None,u'(..*a)di',u'balladi'),
+			      (None,u'(pisto)oli',u'pistooli'),
+			      (None,u'(poli)isi',u'poliisi'),
 			      (None,u'(.*)i',u'banaali'),
                               (u'nt',u'(.*n)ti',u'hollanti'),
 			      (u'nk',u'(.*n)ki',u'killinki'),
@@ -101,7 +103,8 @@ historical = [
         (u'laittaa', u'sw', [(u'tt',u'(.*t)tAA',u'laittaa')]),
 	(u'lampi', u'-',   [(None,u'(.*kam)pi',u'lampi')]),
 	(u'lovi', u'sw',   [(None,u'(rips|sin)i',u'kiiski')]),
-	(u'nainen', u'-', [(None,u'(.*Co)rinen',u'allegorinen'),
+	(u'nainen', u'-', [(None,u'(hevo)nen',u'hevoinen'),
+			   (None,u'(.*Co)rinen',u'allegorinen'),
 			   (None,u'(.*Co)finen',u'filosofinen'),
 			   (None,u'(.*Co)ginen',u'psykologinen'),
 			   (None,u'(.*Co)ninen',u'ironinen'),
@@ -127,6 +130,9 @@ historical = [
 			     (None,u'(..*[^aeouyäö]o)ni',u'symboli_ni'),
 			     (None,u'(..*[^aeouyäö]o)ri',u'symboli_ri'),
 			     (None,u'(..*[^aeouyäö]o)vi',u'symboli_vi'),
+			     (None,u'(kam)ari',u'kamari'),
+			     (None,u'(pisto)oli',u'pistooli'),
+			     (None,u'(poli)isi',u'poliisi'),
 			     (None,u'(..*a)di',u'balladi')]),
         (u'pasuuna', u'sw', [(None,u'(.*)A',u'pasuuna')]),
 	(u'punoa',   u'sw', [(u't',u'(...*AU)tUA',u'antautua')]),
@@ -162,8 +168,8 @@ historical = [
         (u'virkkaa', u'sw', [(u'kk',u'(.*k)kAA',u'virkkaa')])
         ]
 
-classmap = historical
-classmap.extend(hfconv.modern_classmap)
+classmap = hfconv.compileClassmapREs(historical)
+classmap.extend(hfconv.compileClassmapREs(hfconv.modern_classmap))
 
 pattern = u"^(?P<alku>.*)(?:" + \
 	  u"(?P<keltainen>C[aouyäö]i?nen)|" + \
